[build-system]
requires = ["uv-build>=0.4.0"]          # use uv for super-fast local builds
build-backend = "uv_build.api"

[project]
name = "peagen-template-{{ org | replace('_', '-') }}-{{ PROJECT_ROOT | replace('_', '-') }}"
version = "0.1.0"
description = "Template-set '{{ PROJECT_ROOT }}' for Peagen."
authors = [{name = "{{ org | title }}"}]
readme = "README.md"
requires-python = ">=3.9"
keywords = ["peagen-template-set"]
classifiers = [
  "Framework :: Peagen :: Template Set",
  "Programming Language :: Python :: 3",
]

[project.entry-points."peagen.template_sets"]
{{ PROJECT_ROOT }} = "peagen_template_{{ org }}_{{ PROJECT_ROOT }}.templates"

[tool.uv]
# pass extra flags to uv if desired
pip-extra-args = ["--no-build-isolation"]
