# Factor table – edit levels or add new factors as needed.

LLM_FACTORS:
  # these keys will end up under META.LLM_FACTORS in the payload
  temperature:
    - 0.2
    - 0.7
  model:
    - gpt-4o-mini
    - gpt-4o-max

FACTORS:
  # other non-LLM experimental knobs
  dataset:
    - news
    - tweets

PATCHES:
  # Example: override provider when model == gpt-4o-max
  - when:
      model: gpt-4o-max
    apply:
      - op:   replace
        path: /PROJECTS/0/PKGS/0/PROVIDER
        value: azure-openai

  # …add your own patches…
